view: Convenient function for viewing any rectangular data file in...

Description Usage Arguments Details Value Author(s) Examples

View source: R/view.R

Description

You can use this function for loading any data.frame, data_frame, tbl_df, matrix, vector objects into your system-default spreadsheet software (e.g., Excel). This function has been inspired by DataViewer and has implemented Hadley Wickham's write_csv instead of the default write.csv for a better performance.

Usage

1
view(x, ...)

Arguments

x

An object of class data.frame, matrix, or vector.

...

Any additional arguments available for write_csv.

Details

view

See example below.

Value

Data object opened in a preferable spreadsheet application window.

Author(s)

JooYoung Seo, jooyoung@psu.edu

Soyoung Choi, sxc940@psu.edu

Examples

1
2
3
4
5
6
7
8
if(interactive()) {
library(ezviewr)
data(airquality)
str(airquality)
## View your data object in your spreadsheet software:
view(airquality)
# Then, when necessary, you can modify the opened data in the spreadsheet and save it as a new data.
}

jooyoungseo/ezviewr documentation built on Dec. 2, 2019, 9:52 p.m.