Description Usage Arguments Details Value Author(s) Examples
You can use this function for loading any data.frame, data_frame, tbl_df, matrix, vector objects into your system-default spreadsheet software (e.g., Excel). This function has been inspired by DataViewer and has implemented Hadley Wickham's write_csv instead of the default write.csv for a better performance.
1 |
x |
An object of class data.frame, matrix, or vector. |
... |
Any additional arguments available for write_csv. |
view
See example below.
Data object opened in a preferable spreadsheet application window.
JooYoung Seo, jooyoung@psu.edu
Soyoung Choi, sxc940@psu.edu
1 2 3 4 5 6 7 8 | if(interactive()) {
library(ezviewr)
data(airquality)
str(airquality)
## View your data object in your spreadsheet software:
view(airquality)
# Then, when necessary, you can modify the opened data in the spreadsheet and save it as a new data.
}
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.